@@ -11,6 +11,7 @@
 
 #include "ServiceBroker.h"
 #include "settings/AdvancedSettings.h"
+#include "settings/DisplaySettings.h"
 #include "settings/Settings.h"
 #include "FileItem.h"
 #include "music/tags/MusicInfoTag.h"
@@ -572,8 +573,7 @@ XBMCController *g_xbmcController;
     self.view.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
     self.view.autoresizesSubviews = YES;
 
-    m_glView = [[IOSEAGLView alloc] initWithFrame:[self fullscreenSubviewFrame]
-                                     withScreen:UIScreen.mainScreen];
+    m_glView = [[IOSEAGLView alloc] initWithFrame:self.view.bounds withScreen:UIScreen.mainScreen];
     [[IOSScreenManager sharedInstance] setView:m_glView];
     [m_glView setMultipleTouchEnabled:YES];
 
@@ -686,6 +686,46 @@ XBMCController *g_xbmcController;
     return rect;
 }
 //--------------------------------------------------------------
+- (void)onXbmcAlive
+{
+  [self setGUIInsetsFromMainThread:NO];
+}
+//--------------------------------------------------------------
+- (void)setGUIInsetsFromMainThread:(BOOL)isMainThread
+{
+  auto& guiInsets = CDisplaySettings::GetInstance().GetCurrentResolutionInfo().guiInsets;
+
+  // disable insets for external screen
+  if ([[IOSScreenManager sharedInstance] isExternalScreen])
+  {
+    guiInsets = EdgeInsets{};
+    return;
+  }
+
+  // apply safe area to Kodi GUI
+  if (@available(ios 11.0, *))
+  {
+    UIEdgeInsets __block insets;
+    auto getInsets = ^{
+      insets = m_window.safeAreaInsets;
+    };
+    if (isMainThread)
+      getInsets();
+    else
+      dispatch_sync(dispatch_get_main_queue(), getInsets);
+
+    CLog::Log(LOGDEBUG, "insets: {}\nwindow: {}\nscreen: {}",
+              NSStringFromUIEdgeInsets(insets).UTF8String, m_window.description.UTF8String,
+              m_glView.currentScreen.description.UTF8String);
+    if (UIEdgeInsetsEqualToEdgeInsets(insets, UIEdgeInsetsZero))
+      return;
+
+    auto scale = [m_glView getScreenScale:m_glView.currentScreen];
+    guiInsets = EdgeInsets(insets.left * scale, insets.top * scale, insets.right * scale,
+                           insets.bottom * scale);
+  }
+}
+//--------------------------------------------------------------
 - (void) setFramebuffer
 {
   [m_glView setFramebuffer];
